@@ -229,7 +229,9 @@ def set_vars(
         f"Setting {len(ordered_keys)} variable(s) in envchain namespace '{namespace}'."
     )
 
-    stdout, stderr = _run_envchain_command(envchain_cmd_list, input_payload_str)
+    stdout, stderr = _run_envchain_command(
+        envchain_cmd_list, input_payload_str, envchain_cmd=envchain_cmd
+    )
 
     logger.info(
         f"envchain successfully processed set operation for namespace '{namespace}'."
@@ -330,7 +332,7 @@ def unset_vars(
         f"Unsetting {len(stripped_keys)} variable(s) in envchain namespace '{namespace}'."
     )
 
-    stdout, stderr = _run_envchain_command(envchain_cmd_list)
+    stdout, stderr = _run_envchain_command(envchain_cmd_list, envchain_cmd=envchain_cmd)
 
     logger.info(
         f"envchain successfully processed unset operation for namespace '{namespace}'."
@@ -355,7 +357,7 @@ def list_namespaces(envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND) -> list[str]:
     envchain_cmd_list = [envchain_cmd, "--list"]
     logger.info("Listing all envchain namespaces.")
 
-    stdout, stderr = _run_envchain_command(envchain_cmd_list)
+    stdout, stderr = _run_envchain_command(envchain_cmd_list, envchain_cmd=envchain_cmd)
 
     if stderr:
         logger.warning(f"envchain stderr (list_namespaces):\n{stderr}")
@@ -417,7 +419,7 @@ def list_keys_in_namespace(
     envchain_cmd_list = [envchain_cmd, "--list", namespace]
     logger.info(f"Listing keys in envchain namespace '{namespace}'.")
 
-    stdout, stderr = _run_envchain_command(envchain_cmd_list)
+    stdout, stderr = _run_envchain_command(envchain_cmd_list, envchain_cmd=envchain_cmd)
     # Raise if stderr indicates namespace not defined
     if stderr and "not defined" in stderr.lower():
         raise EnvchainError(f"Namespace '{namespace}' does not exist.")
@@ -469,7 +471,9 @@ def get_vars(
         logger.debug(f"Filtering for keys: {', '.join(keys_to_filter)}")
 
     try:
-        stdout, stderr = _run_envchain_command(envchain_cmd_list)
+        stdout, stderr = _run_envchain_command(
+            envchain_cmd_list, envchain_cmd=envchain_cmd
+        )
     except EnvchainError as e:
         # If namespace does not exist, treat as empty
         if e.stderr and "not defined" in e.stderr.lower():
